package com.logicbig.example;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;


@SpringBootApplication
public class SpringBootSecurityExampleMain {

    @Bean
    public WebSecurityConfigurerAdapter webSecurityConfig() {
        return new WebSecurityConfigurerAdapter() {
            @Override
            protected void configure(HttpSecurity http) throws Exception {
                http.authorizeRequests()
                    .anyRequest().authenticated()
                    .and()
                    .formLogin();
            }

            @Override
            protected void configure(AuthenticationManagerBuilder builder) throws Exception {
                BCryptPasswordEncoder passwordEncoder = new BCryptPasswordEncoder();
                builder.inMemoryAuthentication().passwordEncoder(passwordEncoder)
                       .withUser("joe").password(passwordEncoder.encode("123")).roles("USER")
                       .and()
                       .withUser("sara").password(passwordEncoder.encode("234")).roles("ADMIN")
                ;
            }
        };
    }

    public static void main(String[] args) {
        SpringApplication.run(SpringBootSecurityExampleMain.class);
    }
}